.. _register-module-reference:

Module Reference
================

I2C
---

`i2c_bit` - Single bit registers
++++++++++++++++++++++++++++++++

.. automodule:: adafruit_register.i2c_bit
   :members:

`i2c_bits` - Multi bit registers
++++++++++++++++++++++++++++++++

.. automodule:: adafruit_register.i2c_bits
    :members:

`i2c_struct` - Generic structured registers based on `struct`
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: adafruit_register.i2c_struct
    :members:

`i2c_bcd_datetime` - Binary Coded Decimal date and time register
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: adafruit_register.i2c_bcd_datetime
  :members:

`i2c_bcd_alarm` - Binary Coded Decimal alarm register
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

.. automodule:: adafruit_register.i2c_bcd_alarm
  :members:

SPI
---
Coming soon!
